[Libreoffice-commits] .: 3 commits - chart2/source cui/source dbaccess/source extensions/source sc/source sd/source sfx2/inc sfx2/source sfx2/uiconfig sfx2/UI_sfx.mk svx/source sw/source

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Thu Jan 24 06:30:07 PST 2013


 chart2/source/controller/dialogs/dlg_NumberFormat.cxx |    2 
 chart2/source/controller/dialogs/dlg_NumberFormat.hxx |    2 
 cui/source/customize/acccfg.cxx                       |    2 
 cui/source/customize/macropg.cxx                      |    2 
 cui/source/dialogs/SpellDialog.cxx                    |    4 
 cui/source/factory/dlgfact.cxx                        |    2 
 cui/source/inc/acccfg.hxx                             |    2 
 cui/source/inc/connect.hxx                            |    4 
 cui/source/inc/cuisrchdlg.hxx                         |    2 
 cui/source/inc/dbregister.hxx                         |    2 
 cui/source/inc/dstribut.hxx                           |    2 
 cui/source/inc/macroass.hxx                           |    2 
 cui/source/inc/measure.hxx                            |    4 
 cui/source/options/cuisrchdlg.cxx                     |    4 
 cui/source/options/dbregister.cxx                     |    4 
 cui/source/tabpages/connect.cxx                       |    2 
 cui/source/tabpages/dstribut.cxx                      |    2 
 cui/source/tabpages/macroass.cxx                      |    2 
 cui/source/tabpages/measure.cxx                       |    2 
 cui/source/tabpages/numfmt.cxx                        |    6 -
 dbaccess/source/ui/dlg/TablesSingleDlg.cxx            |    4 
 dbaccess/source/ui/inc/TablesSingleDlg.hxx            |    2 
 extensions/source/propctrlr/formcomponenthandler.cxx  |    2 
 sc/source/ui/pagedlg/tphf.cxx                         |    2 
 sd/source/ui/dlg/sddlgfact.cxx                        |    2 
 sd/source/ui/dlg/tpaction.cxx                         |    2 
 sd/source/ui/inc/tpaction.hxx                         |    2 
 sfx2/UI_sfx.mk                                        |    1 
 sfx2/inc/sfx2/basedlgs.hxx                            |   44 ++++++++-
 sfx2/inc/sfx2/macropg.hxx                             |    2 
 sfx2/source/dialog/basedlgs.cxx                       |   74 ++++++++++++++--
 sfx2/uiconfig/ui/singletabdialog.ui                   |   80 ++++++++++++++++++
 svx/source/tbxctrls/grafctrl.cxx                      |    2 
 sw/source/ui/chrdlg/drpcps.cxx                        |    2 
 sw/source/ui/chrdlg/tblnumfm.cxx                      |   11 --
 sw/source/ui/config/mailconfigpage.cxx                |    2 
 sw/source/ui/config/optload.cxx                       |    4 
 sw/source/ui/dialog/addrdlg.cxx                       |    2 
 sw/source/ui/dialog/swdlgfact.hxx                     |    4 
 sw/source/ui/fldui/fldedt.cxx                         |    2 
 sw/source/ui/frmdlg/pattern.cxx                       |    2 
 sw/source/ui/frmdlg/uiborder.cxx                      |    2 
 sw/source/ui/frmdlg/wrap.cxx                          |    2 
 sw/source/ui/inc/addrdlg.hxx                          |    2 
 sw/source/ui/inc/drpcps.hxx                           |    2 
 sw/source/ui/inc/fldedt.hxx                           |    2 
 sw/source/ui/inc/mailconfigpage.hxx                   |    2 
 sw/source/ui/inc/optload.hxx                          |    2 
 sw/source/ui/inc/pattern.hxx                          |    2 
 sw/source/ui/inc/tblnumfm.hxx                         |    2 
 sw/source/ui/inc/uiborder.hxx                         |    2 
 sw/source/ui/inc/wrap.hxx                             |    2 
 52 files changed, 242 insertions(+), 82 deletions(-)

New commits:
commit 20371d26374b40fe28ac006d9392104b692fce32
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Jan 24 14:11:21 2013 +0000

    add a layout aware SfxSingleTabDialog
    
    Change-Id: Ia4726eac4448dd22380d81d49c5e3b19aa097f73

diff --git a/sfx2/UI_sfx.mk b/sfx2/UI_sfx.mk
index c5077bb..ca89a1c 100644
--- a/sfx2/UI_sfx.mk
+++ b/sfx2/UI_sfx.mk
@@ -19,6 +19,7 @@ $(eval $(call gb_UI_add_uifiles,sfx,\
 	sfx2/uiconfig/ui/password \
 	sfx2/uiconfig/ui/printeroptionsdialog \
 	sfx2/uiconfig/ui/securityinfopage \
+	sfx2/uiconfig/ui/singletabdialog \
 ))
 
 # vim: set noet sw=4 ts=4:
diff --git a/sfx2/inc/sfx2/basedlgs.hxx b/sfx2/inc/sfx2/basedlgs.hxx
index 141f082..c3684e5 100644
--- a/sfx2/inc/sfx2/basedlgs.hxx
+++ b/sfx2/inc/sfx2/basedlgs.hxx
@@ -64,6 +64,7 @@ protected:
 
     String&             GetExtraData()      { return aExtraData; }
     sal_uInt32          GetUniqId() const   { return nUniqId; }
+    void                SetUniqId(sal_uInt32 nSettingsId)  { nUniqId = nSettingsId; }
     SfxItemSet*         GetItemSet()        { return pOutputSet; }
     void                CreateOutputItemSet( SfxItemPool& rPool );
     void                CreateOutputItemSet( const SfxItemSet& rInput );
@@ -167,21 +168,24 @@ struct SingleTabDlgImpl
 
 typedef sal_uInt16* (*GetTabPageRanges)(); // liefert internationale Which-Werte
 
-class SFX2_DLLPUBLIC SfxNoLayoutSingleTabDialog : public SfxModalDialog
+class SFX2_DLLPUBLIC SfxSingleTabDialogBase : public SfxModalDialog
 {
 public:
-    SfxNoLayoutSingleTabDialog( Window* pParent, const SfxItemSet& rOptionsSet, sal_uInt16 nUniqueId );
-    SfxNoLayoutSingleTabDialog( Window* pParent, sal_uInt16 nUniqueId, const SfxItemSet* pInSet = 0 );
+    //layout ctor
+    SfxSingleTabDialogBase(Window* pParent, const SfxItemSet& rOptionsSet);
 
-    virtual             ~SfxNoLayoutSingleTabDialog();
+    //non-layout ctors
+    SfxSingleTabDialogBase( Window* pParent, const SfxItemSet& rOptionsSet, sal_uInt16 nUniqueId );
+    SfxSingleTabDialogBase( Window* pParent, sal_uInt16 nUniqueId, const SfxItemSet* pInSet = 0 );
+
+    virtual             ~SfxSingleTabDialogBase();
 
-    void                SetTabPage( SfxTabPage* pTabPage, GetTabPageRanges pRangesFunc = 0 );
     SfxTabPage*         GetTabPage() const { return pImpl->m_pSfxPage; }
 
     OKButton*           GetOKButton() const { return pOKBtn; }
     CancelButton*       GetCancelButton() const { return pCancelBtn; }
 
-private:
+protected:
     GetTabPageRanges    fnGetRanges;
 
     OKButton*           pOKBtn;
@@ -193,6 +197,32 @@ private:
     DECL_DLLPRIVATE_LINK(OKHdl_Impl, void *);
 };
 
+class SFX2_DLLPUBLIC SfxSingleTabDialog : public SfxSingleTabDialogBase
+{
+public:
+    SfxSingleTabDialog(Window* pParent, const SfxItemSet& rOptionsSet)
+        : SfxSingleTabDialogBase(pParent, rOptionsSet)
+    {
+    }
+    void setTabPage(SfxTabPage* pTabPage, GetTabPageRanges pRangesFunc = 0, sal_uInt32 nSettingsId = 0);
+};
+
+//Old school deprecated non-layout aware version
+class SFX2_DLLPUBLIC SfxNoLayoutSingleTabDialog : public SfxSingleTabDialogBase
+{
+public:
+    SfxNoLayoutSingleTabDialog(Window* pParent, const SfxItemSet& rOptionsSet, sal_uInt16 nUniqueId)
+        : SfxSingleTabDialogBase(pParent, rOptionsSet, nUniqueId)
+    {
+    }
+    SfxNoLayoutSingleTabDialog(Window* pParent, sal_uInt16 nUniqueId, const SfxItemSet* pInSet = 0)
+        : SfxSingleTabDialogBase(pParent, nUniqueId, pInSet)
+    {
+    }
+    ~SfxNoLayoutSingleTabDialog();
+    void SetTabPage(SfxTabPage* pTabPage, GetTabPageRanges pRangesFunc = 0);
+};
+
 #endif
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/sfx2/source/dialog/basedlgs.cxx b/sfx2/source/dialog/basedlgs.cxx
index 31b39bd..06a361a 100644
--- a/sfx2/source/dialog/basedlgs.cxx
+++ b/sfx2/source/dialog/basedlgs.cxx
@@ -668,9 +668,9 @@ void SfxFloatingWindow::FillInfo(SfxChildWinInfo& rInfo) const
         rInfo.nFlags |= SFX_CHILDWIN_ZOOMIN;
 }
 
-// SfxNoLayoutSingleTabDialog ----------------------------------------------------
+// SfxSingleTabDialogBase ----------------------------------------------------
 
-IMPL_LINK_NOARG(SfxNoLayoutSingleTabDialog, OKHdl_Impl)
+IMPL_LINK_NOARG(SfxSingleTabDialogBase, OKHdl_Impl)
 
 /*  [Description]
 
@@ -718,7 +718,7 @@ IMPL_LINK_NOARG(SfxNoLayoutSingleTabDialog, OKHdl_Impl)
 
 // -----------------------------------------------------------------------
 
-SfxNoLayoutSingleTabDialog::SfxNoLayoutSingleTabDialog
+SfxSingleTabDialogBase::SfxSingleTabDialogBase
 (
     Window *pParent,
     const SfxItemSet& rSet,
@@ -744,7 +744,7 @@ SfxNoLayoutSingleTabDialog::SfxNoLayoutSingleTabDialog
 
 // -----------------------------------------------------------------------
 
-SfxNoLayoutSingleTabDialog::SfxNoLayoutSingleTabDialog
+SfxSingleTabDialogBase::SfxSingleTabDialogBase
 (
     Window* pParent,
     sal_uInt16 nUniqueId,
@@ -769,18 +769,65 @@ SfxNoLayoutSingleTabDialog::SfxNoLayoutSingleTabDialog
     SetInputSet( pInSet );
 }
 
+SfxSingleTabDialogBase::SfxSingleTabDialogBase(Window *pParent, const SfxItemSet& rSet)
+    : SfxModalDialog(pParent, "SingleTabDialog", "sfx/ui/singletabdialog.ui")
+    , pImpl(new SingleTabDlgImpl)
+{
+    get(pOKBtn, "ok");
+    pOKBtn->SetClickHdl( LINK( this, SfxSingleTabDialogBase, OKHdl_Impl ) );
+    get(pCancelBtn, "cancel");
+    get(pHelpBtn, "help");
+    SetInputSet( &rSet );
+}
+
 // -----------------------------------------------------------------------
 
-SfxNoLayoutSingleTabDialog::~SfxNoLayoutSingleTabDialog()
+SfxSingleTabDialogBase::~SfxSingleTabDialogBase()
 {
-    delete pOKBtn;
-    delete pCancelBtn;
-    delete pHelpBtn;
     delete pImpl->m_pSfxPage;
     delete pImpl->m_pLine;
     delete pImpl;
 }
 
+void SfxSingleTabDialog::setTabPage(SfxTabPage* pTabPage,
+    GetTabPageRanges pRangesFunc, sal_uInt32 nSettingsId)
+/*  [Description]
+
+    Insert a (new) TabPage; an existing page is deleted.
+    The passed on page is initialized with the initially given Itemset
+    through calling Reset().
+*/
+
+{
+    SetUniqId(nSettingsId);
+    delete pImpl->m_pSfxPage;
+    pImpl->m_pSfxPage = pTabPage;
+    fnGetRanges = pRangesFunc;
+
+    if ( pImpl->m_pSfxPage )
+    {
+        // First obtain the user data, only then Reset()
+        SvtViewOptions aPageOpt( E_TABPAGE, String::CreateFromInt32( GetUniqId() ) );
+        String sUserData;
+        Any aUserItem = aPageOpt.GetUserItem( USERITEM_NAME );
+        OUString aTemp;
+        if ( aUserItem >>= aTemp )
+            sUserData = String( aTemp );
+        pImpl->m_pSfxPage->SetUserData( sUserData );
+        pImpl->m_pSfxPage->Reset( *GetInputItemSet() );
+        pImpl->m_pSfxPage->Show();
+
+        pHelpBtn->Show(Help::IsContextHelpEnabled());
+
+        // Set TabPage text in the Dialog
+        SetText( pImpl->m_pSfxPage->GetText() );
+
+        // Dialog recieves the HelpId of TabPage
+        SetHelpId( pImpl->m_pSfxPage->GetHelpId() );
+        SetUniqueId( pImpl->m_pSfxPage->GetUniqueId() );
+    }
+}
+
 // -----------------------------------------------------------------------
 
 void SfxNoLayoutSingleTabDialog::SetTabPage( SfxTabPage* pTabPage,
@@ -796,7 +843,7 @@ void SfxNoLayoutSingleTabDialog::SetTabPage( SfxTabPage* pTabPage,
     if ( !pOKBtn )
     {
         pOKBtn = new OKButton( this, WB_DEFBUTTON );
-        pOKBtn->SetClickHdl( LINK( this, SfxNoLayoutSingleTabDialog, OKHdl_Impl ) );
+        pOKBtn->SetClickHdl( LINK( this, SfxSingleTabDialogBase, OKHdl_Impl ) );
     }
     if ( !pCancelBtn )
         pCancelBtn = new CancelButton( this );
@@ -847,4 +894,11 @@ void SfxNoLayoutSingleTabDialog::SetTabPage( SfxTabPage* pTabPage,
     }
 }
 
+SfxNoLayoutSingleTabDialog::~SfxNoLayoutSingleTabDialog()
+{
+    delete pOKBtn;
+    delete pCancelBtn;
+    delete pHelpBtn;
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/sfx2/uiconfig/ui/singletabdialog.ui b/sfx2/uiconfig/ui/singletabdialog.ui
new file mode 100644
index 0000000..fca8957
--- /dev/null
+++ b/sfx2/uiconfig/ui/singletabdialog.ui
@@ -0,0 +1,80 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<interface>
+  <!-- interface-requires gtk+ 3.0 -->
+  <object class="GtkDialog" id="SingleTabDialog">
+    <property name="can_focus">False</property>
+    <property name="border_width">5</property>
+    <property name="type_hint">dialog</property>
+    <child internal-child="vbox">
+      <object class="GtkBox" id="dialog-vbox1">
+        <property name="can_focus">False</property>
+        <property name="spacing">2</property>
+        <child internal-child="action_area">
+          <object class="GtkButtonBox" id="dialog-action_area1">
+            <property name="can_focus">False</property>
+            <property name="orientation">vertical</property>
+            <property name="layout_style">start</property>
+            <child>
+              <object class="GtkButton" id="ok">
+                <property name="label">gtk-ok</property>
+                <property name="visible">True</property>
+                <property name="can_focus">True</property>
+                <property name="can_default">True</property>
+                <property name="has_default">True</property>
+                <property name="receives_default">True</property>
+                <property name="use_stock">True</property>
+              </object>
+              <packing>
+                <property name="expand">False</property>
+                <property name="fill">True</property>
+                <property name="position">0</property>
+              </packing>
+            </child>
+            <child>
+              <object class="GtkButton" id="cancel">
+                <property name="label">gtk-cancel</property>
+                <property name="visible">True</property>
+                <property name="can_focus">True</property>
+                <property name="receives_default">True</property>
+                <property name="use_stock">True</property>
+              </object>
+              <packing>
+                <property name="expand">False</property>
+                <property name="fill">True</property>
+                <property name="position">1</property>
+              </packing>
+            </child>
+            <child>
+              <object class="GtkButton" id="help">
+                <property name="label">gtk-help</property>
+                <property name="visible">True</property>
+                <property name="can_focus">True</property>
+                <property name="receives_default">True</property>
+                <property name="use_stock">True</property>
+              </object>
+              <packing>
+                <property name="expand">False</property>
+                <property name="fill">True</property>
+                <property name="position">2</property>
+              </packing>
+            </child>
+          </object>
+          <packing>
+            <property name="expand">False</property>
+            <property name="fill">True</property>
+            <property name="pack_type">end</property>
+            <property name="position">0</property>
+          </packing>
+        </child>
+        <child>
+          <placeholder/>
+        </child>
+      </object>
+    </child>
+    <action-widgets>
+      <action-widget response="0">ok</action-widget>
+      <action-widget response="0">cancel</action-widget>
+      <action-widget response="0">help</action-widget>
+    </action-widgets>
+  </object>
+</interface>
diff --git a/sw/source/ui/chrdlg/tblnumfm.cxx b/sw/source/ui/chrdlg/tblnumfm.cxx
index 0b09521..1552f60 100644
--- a/sw/source/ui/chrdlg/tblnumfm.cxx
+++ b/sw/source/ui/chrdlg/tblnumfm.cxx
@@ -30,7 +30,7 @@
 #include <sfx2/tabdlg.hxx>
 
 SwNumFmtDlg::SwNumFmtDlg(Window* pParent, const SfxItemSet& rSet)
-    : SfxNoLayoutSingleTabDialog( pParent, rSet, 0 )
+    : SfxSingleTabDialog(pParent, rSet)
 {
     // Create TabPage
     SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
@@ -39,17 +39,12 @@ SwNumFmtDlg::SwNumFmtDlg(Window* pParent, const SfxItemSet& rSet)
 
     if ( fnCreatePage )
     {
-        SfxTabPage* pNewPage = (*fnCreatePage)( this, rSet );
+        SfxTabPage* pNewPage = (*fnCreatePage)( get_content_area(), rSet );
         SfxAllItemSet aSet(*(rSet.GetPool()));
         aSet.Put ( SvxNumberInfoItem( (const SvxNumberInfoItem&)pNewPage->GetItemSet().Get( SID_ATTR_NUMBERFORMAT_INFO )));
         pNewPage->PageCreated(aSet);
-        SetTabPage(pNewPage);
+        setTabPage(pNewPage);
     }
 }
 
-SwNumFmtDlg::~SwNumFmtDlg()
-{
-}
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/sw/source/ui/inc/tblnumfm.hxx b/sw/source/ui/inc/tblnumfm.hxx
index b2de8e1..8cf3a28 100644
--- a/sw/source/ui/inc/tblnumfm.hxx
+++ b/sw/source/ui/inc/tblnumfm.hxx
@@ -24,12 +24,10 @@
 class Window;
 class SfxItemSet;
 
-class SwNumFmtDlg : public SfxNoLayoutSingleTabDialog
+class SwNumFmtDlg : public SfxSingleTabDialog
 {
 public:
-
      SwNumFmtDlg(Window* pParent, const SfxItemSet& rSet);
-    ~SwNumFmtDlg();
 };
 
 #endif
commit bd272cd3daf873fcc69c2cc794ffda821be7fedf
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Jan 24 13:18:00 2013 +0000

    rename SfxSingleTabDialog to SfxNoLayoutSingleTabDialog
    
    Change-Id: I4922b719bf819879909e9949bf7946f20914d1e5

diff --git a/chart2/source/controller/dialogs/dlg_NumberFormat.cxx b/chart2/source/controller/dialogs/dlg_NumberFormat.cxx
index 06443fa..7639b4b 100644
--- a/chart2/source/controller/dialogs/dlg_NumberFormat.cxx
+++ b/chart2/source/controller/dialogs/dlg_NumberFormat.cxx
@@ -41,7 +41,7 @@ namespace chart
 using namespace ::com::sun::star;
 
 NumberFormatDialog::NumberFormatDialog(Window* pParent, SfxItemSet& rSet)
-    : SfxSingleTabDialog( pParent, rSet, 0 )
+    : SfxNoLayoutSingleTabDialog( pParent, rSet, 0 )
 {
     SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
     ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( RID_SVXPAGE_NUMBERFORMAT );
diff --git a/chart2/source/controller/dialogs/dlg_NumberFormat.hxx b/chart2/source/controller/dialogs/dlg_NumberFormat.hxx
index c574608..31535dd 100644
--- a/chart2/source/controller/dialogs/dlg_NumberFormat.hxx
+++ b/chart2/source/controller/dialogs/dlg_NumberFormat.hxx
@@ -29,7 +29,7 @@ namespace chart
 {
 //.............................................................................
 
-class NumberFormatDialog : public SfxSingleTabDialog
+class NumberFormatDialog : public SfxNoLayoutSingleTabDialog
 {
 public:
      NumberFormatDialog(Window* pParent, SfxItemSet& rSet);
diff --git a/cui/source/customize/acccfg.cxx b/cui/source/customize/acccfg.cxx
index d9125af..bf433d9 100644
--- a/cui/source/customize/acccfg.cxx
+++ b/cui/source/customize/acccfg.cxx
@@ -1541,7 +1541,7 @@ css::uno::Reference< css::frame::XModel > SfxAcceleratorConfigPage::SearchForAlr
 }
 
 SvxShortcutAssignDlg::SvxShortcutAssignDlg( Window* pParent, const uno::Reference< frame::XFrame >& rxDocumentFrame, const SfxItemSet& rSet )
-    : SfxSingleTabDialog( pParent, rSet, 0 )
+    : SfxNoLayoutSingleTabDialog( pParent, rSet, 0 )
 {
     SfxTabPage* pPage = SfxAcceleratorConfigPage::Create( this, rSet );
     pPage->SetFrame( rxDocumentFrame );
diff --git a/cui/source/customize/macropg.cxx b/cui/source/customize/macropg.cxx
index 691c4e7..5370375 100644
--- a/cui/source/customize/macropg.cxx
+++ b/cui/source/customize/macropg.cxx
@@ -950,7 +950,7 @@ SvxMacroAssignSingleTabDialog::~SvxMacroAssignSingleTabDialog()
 
 // -----------------------------------------------------------------------
 
-// According to SfxSingleTabDialog
+// According to SfxNoLayoutSingleTabDialog
 void SvxMacroAssignSingleTabDialog::SetTabPage( SfxTabPage* pTabPage )
 {
     pFixedLine = new FixedLine( this );
diff --git a/cui/source/dialogs/SpellDialog.cxx b/cui/source/dialogs/SpellDialog.cxx
index 135f33d..c397738 100644
--- a/cui/source/dialogs/SpellDialog.cxx
+++ b/cui/source/dialogs/SpellDialog.cxx
@@ -497,8 +497,8 @@ void SpellDialog::StartSpellOptDlg_Impl()
     };
     SfxItemSet aSet( SFX_APP()->GetPool(), aSpellInfos);
     aSet.Put(SfxSpellCheckItem( xSpell, SID_ATTR_SPELL ));
-    SfxSingleTabDialog* pDlg =
-        new SfxSingleTabDialog( this, aSet, RID_SFXPAGE_LINGU );
+    SfxNoLayoutSingleTabDialog* pDlg =
+        new SfxNoLayoutSingleTabDialog( this, aSet, RID_SFXPAGE_LINGU );
     SfxTabPage* pPage = SvxLinguTabPage::Create( pDlg, aSet );
     ( (SvxLinguTabPage*)pPage )->HideGroups( GROUP_MODULES );
     pDlg->SetTabPage( pPage );
diff --git a/cui/source/factory/dlgfact.cxx b/cui/source/factory/dlgfact.cxx
index 09005d3..4ada5e3 100644
--- a/cui/source/factory/dlgfact.cxx
+++ b/cui/source/factory/dlgfact.cxx
@@ -1653,7 +1653,7 @@ SfxAbstractDialog* AbstractDialogFactory_Impl::CreateSfxDialog( Window* pParent,
                                                                         sal_uInt32 nResId
                                                                         )
 {
-    SfxSingleTabDialog* pDlg=NULL;
+    SfxNoLayoutSingleTabDialog* pDlg=NULL;
     switch ( nResId )
     {
         case RID_SVXPAGE_MEASURE :
diff --git a/cui/source/inc/acccfg.hxx b/cui/source/inc/acccfg.hxx
index e3b6431..8742730 100644
--- a/cui/source/inc/acccfg.hxx
+++ b/cui/source/inc/acccfg.hxx
@@ -197,7 +197,7 @@ public:
     void ExpandEntry ( sal_uInt16 nPos, const String &rStr );
 };
 
-class SvxShortcutAssignDlg : public SfxSingleTabDialog
+class SvxShortcutAssignDlg : public SfxNoLayoutSingleTabDialog
 {
 public:
     SvxShortcutAssignDlg(
diff --git a/cui/source/inc/cuisrchdlg.hxx b/cui/source/inc/cuisrchdlg.hxx
index 450dff4..3ee1083 100644
--- a/cui/source/inc/cuisrchdlg.hxx
+++ b/cui/source/inc/cuisrchdlg.hxx
@@ -34,7 +34,7 @@
 
 class SvxJSearchOptionsPage;
 
-class SvxJSearchOptionsDialog : public SfxSingleTabDialog
+class SvxJSearchOptionsDialog : public SfxNoLayoutSingleTabDialog
 {
     sal_Int32                   nInitialTlFlags;
     SvxJSearchOptionsPage  *pPage;
diff --git a/cui/source/inc/dbregister.hxx b/cui/source/inc/dbregister.hxx
index 224b393..8621fe4 100644
--- a/cui/source/inc/dbregister.hxx
+++ b/cui/source/inc/dbregister.hxx
@@ -126,7 +126,7 @@ namespace svx
     //= DatabaseRegistrationDialog
     //====================================================================
     class DatabaseRegistrationDialog    :public RegistrationItemSetHolder
-                                        ,public SfxSingleTabDialog
+                                        ,public SfxNoLayoutSingleTabDialog
     {
     public:
         DatabaseRegistrationDialog( Window* pParent, const SfxItemSet& rAttr );
diff --git a/cui/source/inc/dstribut.hxx b/cui/source/inc/dstribut.hxx
index 22b9d3a..24b16fe 100644
--- a/cui/source/inc/dstribut.hxx
+++ b/cui/source/inc/dstribut.hxx
@@ -67,7 +67,7 @@ public:
     SvxDistributeVertical GetDistributeVer() const { return meDistributeVer; }
 };
 
-class SvxDistributeDialog : public SfxSingleTabDialog
+class SvxDistributeDialog : public SfxNoLayoutSingleTabDialog
 {
     SvxDistributePage*          mpPage;
 
diff --git a/cui/source/inc/macroass.hxx b/cui/source/inc/macroass.hxx
index b7477422..133d88f 100644
--- a/cui/source/inc/macroass.hxx
+++ b/cui/source/inc/macroass.hxx
@@ -106,7 +106,7 @@ public:
     static SfxTabPage* Create( Window* pParent, const SfxItemSet& rAttrSet );
 };
 
-class SfxMacroAssignDlg : public SfxSingleTabDialog
+class SfxMacroAssignDlg : public SfxNoLayoutSingleTabDialog
 {
 public:
     SfxMacroAssignDlg(
diff --git a/cui/source/options/cuisrchdlg.cxx b/cui/source/options/cuisrchdlg.cxx
index fdc01a9..cfc5b98 100644
--- a/cui/source/options/cuisrchdlg.cxx
+++ b/cui/source/options/cuisrchdlg.cxx
@@ -50,7 +50,7 @@
 SvxJSearchOptionsDialog::SvxJSearchOptionsDialog(
             Window *pParent,
             const SfxItemSet& rOptionsSet, sal_Int32 nInitialFlags ) :
-    SfxSingleTabDialog  ( pParent, rOptionsSet, RID_SVXPAGE_JSEARCH_OPTIONS ),
+    SfxNoLayoutSingleTabDialog  ( pParent, rOptionsSet, RID_SVXPAGE_JSEARCH_OPTIONS ),
     nInitialTlFlags( nInitialFlags )
 {
     pPage = (SvxJSearchOptionsPage *)
@@ -63,7 +63,7 @@ SvxJSearchOptionsDialog::SvxJSearchOptionsDialog(
 SvxJSearchOptionsDialog::~SvxJSearchOptionsDialog()
 {
     // pPage will be implicitly destroyed by the
-    // SfxSingleTabDialog destructor
+    // SfxNoLayoutSingleTabDialog destructor
 }
 
 
diff --git a/cui/source/options/dbregister.cxx b/cui/source/options/dbregister.cxx
index d6ccf4f..e6917f2 100644
--- a/cui/source/options/dbregister.cxx
+++ b/cui/source/options/dbregister.cxx
@@ -76,7 +76,7 @@ RegistrationItemSetHolder::~RegistrationItemSetHolder()
 
 DatabaseRegistrationDialog::DatabaseRegistrationDialog( Window* pParent, const SfxItemSet& rInAttrs )
     :RegistrationItemSetHolder( rInAttrs )
-    ,SfxSingleTabDialog( pParent, getRegistrationItems(), RID_SFXPAGE_DBREGISTER )
+    ,SfxNoLayoutSingleTabDialog( pParent, getRegistrationItems(), RID_SFXPAGE_DBREGISTER )
 {
     SfxTabPage* page = DbRegistrationOptionsPage::Create( this, getRegistrationItems() );
 
@@ -90,7 +90,7 @@ DatabaseRegistrationDialog::~DatabaseRegistrationDialog()
 
 short DatabaseRegistrationDialog::Execute()
 {
-    short result = SfxSingleTabDialog::Execute();
+    short result = SfxNoLayoutSingleTabDialog::Execute();
     if ( result == RET_OK )
     {
         DBG_ASSERT( GetOutputItemSet(), "DatabaseRegistrationDialog::Execute: no output items!" );
diff --git a/cui/source/tabpages/connect.cxx b/cui/source/tabpages/connect.cxx
index 1b2eb47..782f63a 100644
--- a/cui/source/tabpages/connect.cxx
+++ b/cui/source/tabpages/connect.cxx
@@ -55,7 +55,7 @@ static sal_uInt16 pRanges[] =
 
 SvxConnectionDialog::SvxConnectionDialog( Window* pParent, const SfxItemSet& rInAttrs,
                                 const SdrView* pSdrView ) :
-        SfxSingleTabDialog( pParent, rInAttrs, RID_SVXPAGE_CONNECTION )
+        SfxNoLayoutSingleTabDialog( pParent, rInAttrs, RID_SVXPAGE_CONNECTION )
 {
     SvxConnectionPage* _pPage = new SvxConnectionPage( this, rInAttrs );
 
diff --git a/cui/source/tabpages/dstribut.cxx b/cui/source/tabpages/dstribut.cxx
index cb09e449..bde1590 100644
--- a/cui/source/tabpages/dstribut.cxx
+++ b/cui/source/tabpages/dstribut.cxx
@@ -44,7 +44,7 @@ SvxDistributeDialog::SvxDistributeDialog(
     const SfxItemSet& rInAttrs,
     SvxDistributeHorizontal eHor,
     SvxDistributeVertical eVer)
-:   SfxSingleTabDialog(pParent, rInAttrs, RID_SVXPAGE_DISTRIBUTE ),
+:   SfxNoLayoutSingleTabDialog(pParent, rInAttrs, RID_SVXPAGE_DISTRIBUTE ),
     mpPage(0L)
 {
     mpPage = new SvxDistributePage(this, rInAttrs, eHor, eVer);
diff --git a/cui/source/tabpages/macroass.cxx b/cui/source/tabpages/macroass.cxx
index e91d3fb..cfa9c8b 100644
--- a/cui/source/tabpages/macroass.cxx
+++ b/cui/source/tabpages/macroass.cxx
@@ -487,7 +487,7 @@ SfxTabPage* SfxMacroTabPage::Create( Window* pParent, const SfxItemSet& rAttrSet
 }
 
 SfxMacroAssignDlg::SfxMacroAssignDlg( Window* pParent, const Reference< XFrame >& rxDocumentFrame, const SfxItemSet& rSet )
-    : SfxSingleTabDialog( pParent, rSet, 0 )
+    : SfxNoLayoutSingleTabDialog( pParent, rSet, 0 )
 {
     SfxTabPage* pPage = SfxMacroTabPage::Create( this, rSet );
     pPage->SetFrame( rxDocumentFrame );
diff --git a/cui/source/tabpages/measure.cxx b/cui/source/tabpages/measure.cxx
index edf5eda..084986f 100644
--- a/cui/source/tabpages/measure.cxx
+++ b/cui/source/tabpages/measure.cxx
@@ -55,7 +55,7 @@ static sal_uInt16 pRanges[] =
 
 SvxMeasureDialog::SvxMeasureDialog( Window* pParent, const SfxItemSet& rInAttrs,
                                 const SdrView* pSdrView ) :
-        SfxSingleTabDialog( pParent, rInAttrs, RID_SVXPAGE_MEASURE )
+        SfxNoLayoutSingleTabDialog( pParent, rInAttrs, RID_SVXPAGE_MEASURE )
 {
     SvxMeasurePage* _pPage = new SvxMeasurePage( this, rInAttrs );
 
diff --git a/cui/source/tabpages/numfmt.cxx b/cui/source/tabpages/numfmt.cxx
index a4b2b6f..9e2cb5e 100644
--- a/cui/source/tabpages/numfmt.cxx
+++ b/cui/source/tabpages/numfmt.cxx
@@ -1135,7 +1135,7 @@ IMPL_LINK( SvxNumberFormatTabPage, DoubleClickHdl_Impl, SvxFontListBox*, pLb )
         }
         else
         {
-            SfxSingleTabDialog* pParent = dynamic_cast< SfxSingleTabDialog* >( GetParent() );
+            SfxNoLayoutSingleTabDialog* pParent = dynamic_cast< SfxNoLayoutSingleTabDialog* >( GetParent() );
             OKButton* pOKButton = pParent ? pParent->GetOKButton() : NULL;
             if ( pOKButton )
                 pOKButton->Click();
diff --git a/dbaccess/source/ui/dlg/TablesSingleDlg.cxx b/dbaccess/source/ui/dlg/TablesSingleDlg.cxx
index 91f292a..78f8b60 100644
--- a/dbaccess/source/ui/dlg/TablesSingleDlg.cxx
+++ b/dbaccess/source/ui/dlg/TablesSingleDlg.cxx
@@ -47,7 +47,7 @@ OTableSubscriptionDialog::OTableSubscriptionDialog(Window* pParent
             ,SfxItemSet* _pItems
             ,const Reference< XComponentContext >& _rxORB
             ,const ::com::sun::star::uno::Any& _aDataSourceName)
-    :SfxSingleTabDialog(pParent,DLG_TABLE_FILTER,_pItems)
+    :SfxNoLayoutSingleTabDialog(pParent,DLG_TABLE_FILTER,_pItems)
     ,m_pImpl( new ODbDataSourceAdministrationHelper( _rxORB, pParent, this ) )
     ,m_bStopExecution(sal_False)
     ,m_pOutSet(_pItems)
@@ -76,7 +76,7 @@ short OTableSubscriptionDialog::Execute()
     short nRet = RET_CANCEL;
     if ( !m_bStopExecution )
     {
-        nRet = SfxSingleTabDialog::Execute();
+        nRet = SfxNoLayoutSingleTabDialog::Execute();
         if ( nRet == RET_OK )
         {
             m_pOutSet->Put(*GetOutputItemSet());
diff --git a/dbaccess/source/ui/inc/TablesSingleDlg.hxx b/dbaccess/source/ui/inc/TablesSingleDlg.hxx
index 31aa380..3c045ef 100644
--- a/dbaccess/source/ui/inc/TablesSingleDlg.hxx
+++ b/dbaccess/source/ui/inc/TablesSingleDlg.hxx
@@ -44,7 +44,7 @@ class ODbDataSourceAdministrationHelper;
     //========================================================================
     //= OTableSubscriptionDialog
     //========================================================================
-    class OTableSubscriptionDialog : public SfxSingleTabDialog, public IItemSetHelper
+    class OTableSubscriptionDialog : public SfxNoLayoutSingleTabDialog, public IItemSetHelper
     {
         ::std::auto_ptr<ODbDataSourceAdministrationHelper>  m_pImpl;
         sal_Bool m_bStopExecution; // set when the dialog should not be executed
diff --git a/extensions/source/propctrlr/formcomponenthandler.cxx b/extensions/source/propctrlr/formcomponenthandler.cxx
index fb691d0..7f62516 100644
--- a/extensions/source/propctrlr/formcomponenthandler.cxx
+++ b/extensions/source/propctrlr/formcomponenthandler.cxx
@@ -2723,7 +2723,7 @@ namespace pcr
             aCoreSet.Put( aFormatter );
 
             // a tab dialog with a single page
-            ::std::auto_ptr< SfxSingleTabDialog > pDialog( new SfxSingleTabDialog( impl_getDefaultDialogParent_nothrow(), aCoreSet, 0 ) );
+            ::std::auto_ptr< SfxNoLayoutSingleTabDialog > pDialog( new SfxNoLayoutSingleTabDialog( impl_getDefaultDialogParent_nothrow(), aCoreSet, 0 ) );
             SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
             DBG_ASSERT( pFact, "CreateFactory fail!" );
             ::CreateTabPage fnCreatePage = pFact->GetTabPageCreatorFunc( RID_SVXPAGE_NUMBERFORMAT );
diff --git a/sc/source/ui/pagedlg/tphf.cxx b/sc/source/ui/pagedlg/tphf.cxx
index a4b13ba..e0cc297 100644
--- a/sc/source/ui/pagedlg/tphf.cxx
+++ b/sc/source/ui/pagedlg/tphf.cxx
@@ -228,7 +228,7 @@ IMPL_LINK_NOARG(ScHFPage, HFEditHdl)
     else
     {
         String              aText;
-        SfxSingleTabDialog* pDlg = new SfxSingleTabDialog( this, aDataSet, 42 );
+        SfxNoLayoutSingleTabDialog* pDlg = new SfxNoLayoutSingleTabDialog( this, aDataSet, 42 );
         sal_Bool bRightPage =   aCntSharedBox.IsChecked()
                          || ( SVX_PAGE_LEFT != SvxPageUsage(nPageUsage) );
 
diff --git a/sd/source/ui/dlg/sddlgfact.cxx b/sd/source/ui/dlg/sddlgfact.cxx
index e76b6e1..5084268 100644
--- a/sd/source/ui/dlg/sddlgfact.cxx
+++ b/sd/source/ui/dlg/sddlgfact.cxx
@@ -353,7 +353,7 @@ OUString SdAbstractSfxDialog_Impl::GetText() const
     return pDlg->GetText();
 }
 
-//AbstractSfxSingleTabDialog_Impl end
+//AbstractSfxNoLayoutSingleTabDialog_Impl end
 
 //AbstractSdVectorizeDlg_Impl begin
 const GDIMetaFile& AbstractSdVectorizeDlg_Impl::GetGDIMetaFile() const
diff --git a/sd/source/ui/dlg/tpaction.cxx b/sd/source/ui/dlg/tpaction.cxx
index 01c04d7..b423110 100644
--- a/sd/source/ui/dlg/tpaction.cxx
+++ b/sd/source/ui/dlg/tpaction.cxx
@@ -86,7 +86,7 @@ using namespace com::sun::star::lang;
 
 SdActionDlg::SdActionDlg (
     ::Window* pParent, const SfxItemSet* pAttr, ::sd::View* pView ) :
-        SfxSingleTabDialog  ( pParent, *pAttr, TP_ANIMATION_ACTION ),
+        SfxNoLayoutSingleTabDialog  ( pParent, *pAttr, TP_ANIMATION_ACTION ),
         rOutAttrs           ( *pAttr )
 {
     // FreeResource();
diff --git a/sd/source/ui/inc/tpaction.hxx b/sd/source/ui/inc/tpaction.hxx
index be1dc60..bcf23fa 100644
--- a/sd/source/ui/inc/tpaction.hxx
+++ b/sd/source/ui/inc/tpaction.hxx
@@ -42,7 +42,7 @@ class SdDrawDocument;
 |* Effekte-SingleTab-Dialog
 |*
 \************************************************************************/
-class SdActionDlg : public SfxSingleTabDialog
+class SdActionDlg : public SfxNoLayoutSingleTabDialog
 {
 private:
     const SfxItemSet&   rOutAttrs;
diff --git a/sfx2/inc/sfx2/basedlgs.hxx b/sfx2/inc/sfx2/basedlgs.hxx
index d532f3c..141f082 100644
--- a/sfx2/inc/sfx2/basedlgs.hxx
+++ b/sfx2/inc/sfx2/basedlgs.hxx
@@ -149,7 +149,7 @@ public:
 
 };
 
-// class SfxSingleTabDialog --------------------------------------------------
+// class SfxNoLayoutSingleTabDialog --------------------------------------------------
 
 struct SingleTabDlgImpl
 {
@@ -167,13 +167,13 @@ struct SingleTabDlgImpl
 
 typedef sal_uInt16* (*GetTabPageRanges)(); // liefert internationale Which-Werte
 
-class SFX2_DLLPUBLIC SfxSingleTabDialog : public SfxModalDialog
+class SFX2_DLLPUBLIC SfxNoLayoutSingleTabDialog : public SfxModalDialog
 {
 public:
-    SfxSingleTabDialog( Window* pParent, const SfxItemSet& rOptionsSet, sal_uInt16 nUniqueId );
-    SfxSingleTabDialog( Window* pParent, sal_uInt16 nUniqueId, const SfxItemSet* pInSet = 0 );
+    SfxNoLayoutSingleTabDialog( Window* pParent, const SfxItemSet& rOptionsSet, sal_uInt16 nUniqueId );
+    SfxNoLayoutSingleTabDialog( Window* pParent, sal_uInt16 nUniqueId, const SfxItemSet* pInSet = 0 );
 
-    virtual             ~SfxSingleTabDialog();
+    virtual             ~SfxNoLayoutSingleTabDialog();
 
     void                SetTabPage( SfxTabPage* pTabPage, GetTabPageRanges pRangesFunc = 0 );
     SfxTabPage*         GetTabPage() const { return pImpl->m_pSfxPage; }
diff --git a/sfx2/inc/sfx2/macropg.hxx b/sfx2/inc/sfx2/macropg.hxx
index 2b3bdbe..b3b39d5 100644
--- a/sfx2/inc/sfx2/macropg.hxx
+++ b/sfx2/inc/sfx2/macropg.hxx
@@ -119,7 +119,7 @@ public:
     static SfxTabPage* Create( Window* pParent, const SfxItemSet& rAttrSet );
 };
 
-class SFX2_DLLPUBLIC SfxMacroAssignDlg : public SfxSingleTabDialog
+class SFX2_DLLPUBLIC SfxMacroAssignDlg : public SfxNoLayoutSingleTabDialog
 {
 public:
     SfxMacroAssignDlg(
diff --git a/sfx2/source/dialog/basedlgs.cxx b/sfx2/source/dialog/basedlgs.cxx
index 341e591..31b39bd 100644
--- a/sfx2/source/dialog/basedlgs.cxx
+++ b/sfx2/source/dialog/basedlgs.cxx
@@ -668,9 +668,9 @@ void SfxFloatingWindow::FillInfo(SfxChildWinInfo& rInfo) const
         rInfo.nFlags |= SFX_CHILDWIN_ZOOMIN;
 }
 
-// SfxSingleTabDialog ----------------------------------------------------
+// SfxNoLayoutSingleTabDialog ----------------------------------------------------
 
-IMPL_LINK_NOARG(SfxSingleTabDialog, OKHdl_Impl)
+IMPL_LINK_NOARG(SfxNoLayoutSingleTabDialog, OKHdl_Impl)
 
 /*  [Description]
 
@@ -718,7 +718,7 @@ IMPL_LINK_NOARG(SfxSingleTabDialog, OKHdl_Impl)
 
 // -----------------------------------------------------------------------
 
-SfxSingleTabDialog::SfxSingleTabDialog
+SfxNoLayoutSingleTabDialog::SfxNoLayoutSingleTabDialog
 (
     Window *pParent,
     const SfxItemSet& rSet,
@@ -744,7 +744,7 @@ SfxSingleTabDialog::SfxSingleTabDialog
 
 // -----------------------------------------------------------------------
 
-SfxSingleTabDialog::SfxSingleTabDialog
+SfxNoLayoutSingleTabDialog::SfxNoLayoutSingleTabDialog
 (
     Window* pParent,
     sal_uInt16 nUniqueId,
@@ -771,7 +771,7 @@ SfxSingleTabDialog::SfxSingleTabDialog
 
 // -----------------------------------------------------------------------
 
-SfxSingleTabDialog::~SfxSingleTabDialog()
+SfxNoLayoutSingleTabDialog::~SfxNoLayoutSingleTabDialog()
 {
     delete pOKBtn;
     delete pCancelBtn;
@@ -783,7 +783,7 @@ SfxSingleTabDialog::~SfxSingleTabDialog()
 
 // -----------------------------------------------------------------------
 
-void SfxSingleTabDialog::SetTabPage( SfxTabPage* pTabPage,
+void SfxNoLayoutSingleTabDialog::SetTabPage( SfxTabPage* pTabPage,
                                      GetTabPageRanges pRangesFunc )
 /*  [Description]
 
@@ -796,7 +796,7 @@ void SfxSingleTabDialog::SetTabPage( SfxTabPage* pTabPage,
     if ( !pOKBtn )
     {
         pOKBtn = new OKButton( this, WB_DEFBUTTON );
-        pOKBtn->SetClickHdl( LINK( this, SfxSingleTabDialog, OKHdl_Impl ) );
+        pOKBtn->SetClickHdl( LINK( this, SfxNoLayoutSingleTabDialog, OKHdl_Impl ) );
     }
     if ( !pCancelBtn )
         pCancelBtn = new CancelButton( this );
diff --git a/svx/source/tbxctrls/grafctrl.cxx b/svx/source/tbxctrls/grafctrl.cxx
index 71e9b19..beddeed 100644
--- a/svx/source/tbxctrls/grafctrl.cxx
+++ b/svx/source/tbxctrls/grafctrl.cxx
@@ -880,7 +880,7 @@ void SvxGrafAttrHelper::ExecuteGrafAttr( SfxRequest& rReq, SdrView& rView )
                     aCropDlgAttr.Put( SdrGrafCropItem( aLTSize.Width(), aLTSize.Height(),
                                                     aRBSize.Width(), aRBSize.Height() ) );
 
-                    SfxSingleTabDialog  aCropDialog( SfxViewShell::Current() ? SfxViewShell::Current()->GetWindow() : NULL,
+                    SfxNoLayoutSingleTabDialog  aCropDialog( SfxViewShell::Current() ? SfxViewShell::Current()->GetWindow() : NULL,
                                                     aCropDlgAttr, 950 );
                     const String        aCropStr = SVX_RESSTR( RID_SVXSTR_GRAFCROP );
 
diff --git a/sw/source/ui/chrdlg/drpcps.cxx b/sw/source/ui/chrdlg/drpcps.cxx
index 9e5e493..3ef4051 100644
--- a/sw/source/ui/chrdlg/drpcps.cxx
+++ b/sw/source/ui/chrdlg/drpcps.cxx
@@ -502,7 +502,7 @@ void SwDropCapsPict::_InitPrinter()
 
 SwDropCapsDlg::SwDropCapsDlg(Window *pParent, const SfxItemSet &rSet ) :
 
-    SfxSingleTabDialog(pParent, rSet, 0)
+    SfxNoLayoutSingleTabDialog(pParent, rSet, 0)
 
 {
     SwDropCapsPage* pNewPage = (SwDropCapsPage*) SwDropCapsPage::Create(this, rSet);
diff --git a/sw/source/ui/chrdlg/tblnumfm.cxx b/sw/source/ui/chrdlg/tblnumfm.cxx
index 878d71f..0b09521 100644
--- a/sw/source/ui/chrdlg/tblnumfm.cxx
+++ b/sw/source/ui/chrdlg/tblnumfm.cxx
@@ -30,7 +30,7 @@
 #include <sfx2/tabdlg.hxx>
 
 SwNumFmtDlg::SwNumFmtDlg(Window* pParent, const SfxItemSet& rSet)
-    : SfxSingleTabDialog( pParent, rSet, 0 )
+    : SfxNoLayoutSingleTabDialog( pParent, rSet, 0 )
 {
     // Create TabPage
     SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
diff --git a/sw/source/ui/config/mailconfigpage.cxx b/sw/source/ui/config/mailconfigpage.cxx
index 5dc1a29..05c781a 100644
--- a/sw/source/ui/config/mailconfigpage.cxx
+++ b/sw/source/ui/config/mailconfigpage.cxx
@@ -431,7 +431,7 @@ void SwTestAccountSettingsDialog::Test()
 }
 
 SwMailConfigDlg::SwMailConfigDlg(Window* pParent, SfxItemSet& rSet ) :
-    SfxSingleTabDialog(pParent, rSet, 0)
+    SfxNoLayoutSingleTabDialog(pParent, rSet, 0)
 {
     // create TabPage
     SetTabPage(SwMailConfigPage::Create( this, rSet ));
diff --git a/sw/source/ui/config/optload.cxx b/sw/source/ui/config/optload.cxx
index 6c4d0b7..24cbe9a 100644
--- a/sw/source/ui/config/optload.cxx
+++ b/sw/source/ui/config/optload.cxx
@@ -335,7 +335,7 @@ IMPL_LINK_NOARG(SwLoadOptPage, MetricHdl)
 }
 
 SwCaptionOptDlg::SwCaptionOptDlg(Window* pParent, const SfxItemSet& rSet) :
-    SfxSingleTabDialog(pParent, rSet, 0)
+    SfxNoLayoutSingleTabDialog(pParent, rSet, 0)
 {
     // create TabPage
     SetTabPage((SwCaptionOptPage*) SwCaptionOptPage::Create(this, rSet));
@@ -794,7 +794,7 @@ IMPL_LINK_NOARG(SwCaptionOptPage, ModifyHdl)
 {
     String sFldTypeName = aCategoryBox.GetText();
 
-    SfxSingleTabDialog *pDlg = dynamic_cast<SfxSingleTabDialog*>(GetParent());
+    SfxNoLayoutSingleTabDialog *pDlg = dynamic_cast<SfxNoLayoutSingleTabDialog*>(GetParent());
     PushButton *pBtn = pDlg ? pDlg->GetOKButton() : NULL;
     if (pBtn)
         pBtn->Enable(sFldTypeName.Len() != 0);
diff --git a/sw/source/ui/dialog/addrdlg.cxx b/sw/source/ui/dialog/addrdlg.cxx
index ecff912..0a9ebdc 100644
--- a/sw/source/ui/dialog/addrdlg.cxx
+++ b/sw/source/ui/dialog/addrdlg.cxx
@@ -23,7 +23,7 @@
 
 SwAddrDlg::SwAddrDlg(Window* pParent, const SfxItemSet& rSet ) :
 
-    SfxSingleTabDialog(pParent, rSet, 0)
+    SfxNoLayoutSingleTabDialog(pParent, rSet, 0)
 
 {
     SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
diff --git a/sw/source/ui/dialog/swdlgfact.hxx b/sw/source/ui/dialog/swdlgfact.hxx
index f4e84fc..998bcbd 100644
--- a/sw/source/ui/dialog/swdlgfact.hxx
+++ b/sw/source/ui/dialog/swdlgfact.hxx
@@ -22,7 +22,7 @@
 #include "swabstdlg.hxx"
 
 class SwInsertAbstractDlg;
-class SfxSingleTabDialog;
+class SfxNoLayoutSingleTabDialog;
 class SwAsciiFilterDlg;
 class Dialog;
 class SwBreakDlg;
@@ -85,7 +85,7 @@ class AbstractSwInsertAbstractDlg_Impl : public AbstractSwInsertAbstractDlg
 //add for SwInsertAbstractDlg end
 
 // add for SwAddrDlg, SwDropCapsDlg, SwBackgroundDlg SwNumFmtDlg  SwWrapDlg SwBorderDlg, SwFldEditDlg  begin
-class SfxSingleTabDialog;
+class SfxNoLayoutSingleTabDialog;
 class SwAbstractSfxDialog_Impl :public SfxAbstractDialog
 {
     DECL_ABSTDLG_BASE(SwAbstractSfxDialog_Impl,SfxModalDialog)
diff --git a/sw/source/ui/fldui/fldedt.cxx b/sw/source/ui/fldui/fldedt.cxx
index f8ade47..a00eaaf 100644
--- a/sw/source/ui/fldui/fldedt.cxx
+++ b/sw/source/ui/fldui/fldedt.cxx
@@ -53,7 +53,7 @@ namespace swui
 }
 
 SwFldEditDlg::SwFldEditDlg(SwView& rVw) :
-    SfxSingleTabDialog(&rVw.GetViewFrame()->GetWindow(), 0, 0),
+    SfxNoLayoutSingleTabDialog(&rVw.GetViewFrame()->GetWindow(), 0, 0),
     pSh         (rVw.GetWrtShellPtr()),
     aPrevBT     (this, SW_RES(BTN_FLDEDT_PREV)),
     aNextBT     (this, SW_RES(BTN_FLDEDT_NEXT)),
diff --git a/sw/source/ui/frmdlg/pattern.cxx b/sw/source/ui/frmdlg/pattern.cxx
index 997e908..4b5b2ff 100644
--- a/sw/source/ui/frmdlg/pattern.cxx
+++ b/sw/source/ui/frmdlg/pattern.cxx
@@ -32,7 +32,7 @@ Ctor
 
 SwBackgroundDlg::SwBackgroundDlg(Window* pParent, const SfxItemSet& rSet) :
 
-    SfxSingleTabDialog(pParent, rSet, 0)
+    SfxNoLayoutSingleTabDialog(pParent, rSet, 0)
 
 {
     SetText(SW_RESSTR(STR_FRMUI_PATTERN));
diff --git a/sw/source/ui/frmdlg/uiborder.cxx b/sw/source/ui/frmdlg/uiborder.cxx
index f8342e7..2f4b1ef 100644
--- a/sw/source/ui/frmdlg/uiborder.cxx
+++ b/sw/source/ui/frmdlg/uiborder.cxx
@@ -34,7 +34,7 @@
 
 SwBorderDlg::SwBorderDlg(Window* pParent, SfxItemSet& rSet, sal_uInt16 nType) :
 
-    SfxSingleTabDialog(pParent, rSet, 0)
+    SfxNoLayoutSingleTabDialog(pParent, rSet, 0)
 
 {
     SetText(SW_RESSTR(STR_FRMUI_BORDER));
diff --git a/sw/source/ui/frmdlg/wrap.cxx b/sw/source/ui/frmdlg/wrap.cxx
index d668cc6..cfba070 100644
--- a/sw/source/ui/frmdlg/wrap.cxx
+++ b/sw/source/ui/frmdlg/wrap.cxx
@@ -52,7 +52,7 @@ static sal_uInt16 aWrapPageRg[] = {
 };
 
 SwWrapDlg::SwWrapDlg(Window* pParent, SfxItemSet& rSet, SwWrtShell* pSh, sal_Bool bDrawMode) :
-    SfxSingleTabDialog(pParent, rSet, 0),
+    SfxNoLayoutSingleTabDialog(pParent, rSet, 0),
     pWrtShell(pSh)
 
 {
diff --git a/sw/source/ui/inc/addrdlg.hxx b/sw/source/ui/inc/addrdlg.hxx
index 5260355..a39bd49 100644
--- a/sw/source/ui/inc/addrdlg.hxx
+++ b/sw/source/ui/inc/addrdlg.hxx
@@ -21,7 +21,7 @@
 
 #include <sfx2/basedlgs.hxx>
 
-class SwAddrDlg : public SfxSingleTabDialog
+class SwAddrDlg : public SfxNoLayoutSingleTabDialog
 {
 public:
 
diff --git a/sw/source/ui/inc/drpcps.hxx b/sw/source/ui/inc/drpcps.hxx
index ef52dcc..c6784d4 100644
--- a/sw/source/ui/inc/drpcps.hxx
+++ b/sw/source/ui/inc/drpcps.hxx
@@ -36,7 +36,7 @@ class SwWrtShell;
 
 // class SwDropCapsDlg ******************************************************
 
-class SwDropCapsDlg : public SfxSingleTabDialog
+class SwDropCapsDlg : public SfxNoLayoutSingleTabDialog
 {
 
 public:
diff --git a/sw/source/ui/inc/fldedt.hxx b/sw/source/ui/inc/fldedt.hxx
index c4527b9..c547c68 100644
--- a/sw/source/ui/inc/fldedt.hxx
+++ b/sw/source/ui/inc/fldedt.hxx
@@ -24,7 +24,7 @@
 class SwView;
 class SwWrtShell;
 
-class SwFldEditDlg : public SfxSingleTabDialog
+class SwFldEditDlg : public SfxNoLayoutSingleTabDialog
 {
     SwWrtShell* pSh;
     ImageButton aPrevBT;
diff --git a/sw/source/ui/inc/mailconfigpage.hxx b/sw/source/ui/inc/mailconfigpage.hxx
index 53e4f3c..f6db44f 100644
--- a/sw/source/ui/inc/mailconfigpage.hxx
+++ b/sw/source/ui/inc/mailconfigpage.hxx
@@ -77,7 +77,7 @@ public:
 
 };
 
-class SwMailConfigDlg : public SfxSingleTabDialog
+class SwMailConfigDlg : public SfxNoLayoutSingleTabDialog
 {
 public:
 
diff --git a/sw/source/ui/inc/optload.hxx b/sw/source/ui/inc/optload.hxx
index 6a709fb..9e27d5a 100644
--- a/sw/source/ui/inc/optload.hxx
+++ b/sw/source/ui/inc/optload.hxx
@@ -77,7 +77,7 @@ public:
     virtual void        Reset( const SfxItemSet& rSet );
 };
 
-class SwCaptionOptDlg : public SfxSingleTabDialog
+class SwCaptionOptDlg : public SfxNoLayoutSingleTabDialog
 {
 public:
      SwCaptionOptDlg(Window* pParent, const SfxItemSet& rSet);
diff --git a/sw/source/ui/inc/pattern.hxx b/sw/source/ui/inc/pattern.hxx
index f3adfe8..66f9a5c 100644
--- a/sw/source/ui/inc/pattern.hxx
+++ b/sw/source/ui/inc/pattern.hxx
@@ -24,7 +24,7 @@
 class Window;
 class SfxItemSet;
 
-class SwBackgroundDlg : public SfxSingleTabDialog
+class SwBackgroundDlg : public SfxNoLayoutSingleTabDialog
 {
 public:
 
diff --git a/sw/source/ui/inc/tblnumfm.hxx b/sw/source/ui/inc/tblnumfm.hxx
index 7499308..b2de8e1 100644
--- a/sw/source/ui/inc/tblnumfm.hxx
+++ b/sw/source/ui/inc/tblnumfm.hxx
@@ -24,7 +24,7 @@
 class Window;
 class SfxItemSet;
 
-class SwNumFmtDlg : public SfxSingleTabDialog
+class SwNumFmtDlg : public SfxNoLayoutSingleTabDialog
 {
 public:
 
diff --git a/sw/source/ui/inc/uiborder.hxx b/sw/source/ui/inc/uiborder.hxx
index a8890b4..20e5e87 100644
--- a/sw/source/ui/inc/uiborder.hxx
+++ b/sw/source/ui/inc/uiborder.hxx
@@ -24,7 +24,7 @@
 class Window;
 class SfxItemSet;
 
-class SwBorderDlg : public SfxSingleTabDialog
+class SwBorderDlg : public SfxNoLayoutSingleTabDialog
 {
 public:
 
diff --git a/sw/source/ui/inc/wrap.hxx b/sw/source/ui/inc/wrap.hxx
index 6e57b92..30587dc 100644
--- a/sw/source/ui/inc/wrap.hxx
+++ b/sw/source/ui/inc/wrap.hxx
@@ -34,7 +34,7 @@ class Window;
 class SfxItemSet;
 class SwWrtShell;
 
-class SwWrapDlg : public SfxSingleTabDialog
+class SwWrapDlg : public SfxNoLayoutSingleTabDialog
 {
     SwWrtShell*         pWrtShell;
 
commit 5f1e50030cdb3a4eacc3b78b2e197a7f57219bcb
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Jan 24 14:28:33 2013 +0000

    set a default height for the number format category
    
    Change-Id: Ic119128aa433f76bcd8684b245d7db60ed3bcf36

diff --git a/cui/source/tabpages/numfmt.cxx b/cui/source/tabpages/numfmt.cxx
index 09ea455..a4b2b6f 100644
--- a/cui/source/tabpages/numfmt.cxx
+++ b/cui/source/tabpages/numfmt.cxx
@@ -239,7 +239,6 @@ SvxNumberFormatTabPage::SvxNumberFormatTabPage(Window* pParent,
     get(m_pLbLanguage, "languagelb");
     get(m_pCbSourceFormat, "sourceformat");
     get(m_pWndPreview, "preview");
-    m_pWndPreview->set_height_request(GetTextHeight()*3);
     get(m_pFtOptions, "optionsft");
     get(m_pFtDecimals, "decimalsft");
     get(m_pEdDecimals, "decimalsed");
@@ -255,6 +254,9 @@ SvxNumberFormatTabPage::SvxNumberFormatTabPage(Window* pParent,
     get(m_pFtComment, "commentft");
     get(m_pEdComment, "commented");
 
+    m_pLbCategory->SetDropDownLineCount(8);
+    m_pWndPreview->set_height_request(GetTextHeight()*3);
+
     Init_Impl();
     SetExchangeSupport(); // this page needs ExchangeSupport
     nFixedCategory=-1;


More information about the Libreoffice-commits mailing list
diff --git a/cui/source/inc/connect.hxx b/cui/source/inc/connect.hxx
index 99495f0..78638ef 100644
--- a/cui/source/inc/connect.hxx
+++ b/cui/source/inc/connect.hxx
@@ -83,9 +83,9 @@ public:
     virtual void PageCreated (SfxAllItemSet aSet);
 };
 
 /* Derived from SfxSingleTabDialog, in order to be informed about
    virtual methods by the control. */
-class SvxConnectionDialog : public SfxSingleTabDialog
+class SvxConnectionDialog : public SfxNoLayoutSingleTabDialog
 {
 public:
     SvxConnectionDialog( Window* pParent, const SfxItemSet& rAttr,
@@ -83,9 +83,9 @@ public:
 };
 
-/* Derived from SfxSingleTabDialog, in order to be informed about
+/* Derived from SfxNoLayoutSingleTabDialog, in order to be informed about
    virtual methods by the control. */
diff --git a/cui/source/inc/measure.hxx b/cui/source/inc/measure.hxx
index be0c0db..6606a2e 100644
--- a/cui/source/inc/measure.hxx
+++ b/cui/source/inc/measure.hxx
@@ -92,9 +92,9 @@ public:
     virtual void PageCreated (SfxAllItemSet aSet);
 };
 
 /* Derived from SfxSingleTabDialog, in order to be able to be
    informed about virtual methods by the control. */
-class SvxMeasureDialog : public SfxSingleTabDialog
+class SvxMeasureDialog : public SfxNoLayoutSingleTabDialog
 {
 public:
     SvxMeasureDialog( Window* pParent, const SfxItemSet& rAttr,
@@ -92,9 +92,9 @@ public:
 };
 
-/* Derived from SfxSingleTabDialog, in order to be able to be
+/* Derived from SfxNoLayoutSingleTabDialog, in order to be able to be
    informed about virtual methods by the control. */